import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.*;

public class Exchange {
	public static void main(String[] args) {
		JFrame frame = new JFrame("Exchange");
		frame.add(new ExchangePanel());
		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		frame.pack();
		frame.setVisible(true);
	}
}

class ExchangePanel extends JPanel {

	private JTextField skrValue; // input
	private JLabel usdValue; // result
	private ExchangeModel model = new ExchangeModel(7); // USD vs. SKR

	ExchangePanel() {
		JLabel skrLabel = new JLabel("Svenska kronor: ");
		JLabel usdLabel = new JLabel("USDollar: ");
		skrValue = new JTextField(8);
		usdValue = new JLabel("---");

		this.add(skrLabel);
		this.add(skrValue);
		this.add(usdLabel);
		this.add(usdValue);

		this.setPreferredSize(new Dimension(200, 100));

		// Create and add listener
		skrValue.addActionListener(new ExchangeListener());
	}

	void onSKRValueEntered() {
		try {
			int input = Integer.parseInt(skrValue.getText());
			int res = model.calculateValue(input);
			usdValue.setText("" + res);

		} catch (Exception e) {
			skrValue.setText("Ange hela kronor!");
		}
	}

	private class ExchangeListener implements ActionListener {
		public void actionPerformed(ActionEvent e) {
			onSKRValueEntered();
		}
	}

	private static final long serialVersionUID = 1L;
}

/**
 * This class implements the "logic" concerned with calculating exchange rates.
 */
class ExchangeModel {

	private final int rate;

	public ExchangeModel(int rate) {
		this.rate = rate;
	}

	public int calculateValue(int value) throws IllegalArgumentException {
		if (value <= 0)
			throw new IllegalArgumentException("value negative");
		return value / rate;
	}
}